# cole Library Reference Manual

Copyright © 1998, 1999 by Roberto Arturo Tena Sánchez

Table of Contents
1. Introduction
  What is cole?
  Features
  Requirements to compile
2. How to compile cole
3. cole Library
  API — Public cole API for the present release.
  Internals — cole internals - don't trust in anything here, because it may (and will) change.
4. Bugs
5. Legal issues
  Distribution and Freedom
  Trademarks
  Copyright and disclaimer
6. GNU GENERAL PUBLIC LICENSE
  Preamble
  TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION
  How to Apply These Terms to Your New Programs

|  | Next
|  | Introduction